import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import RSI


class SMATest(TestCase):

    def test_up(self):
        rsi = RSI(window=2, fillna=True)
        self.assertEqual(rsi.update(10), 50)
        self.assertEqual(rsi.update(11), 100)

    def test_down(self):
        rsi = RSI(window=2, fillna=True)
        self.assertEqual(rsi.update(10), 50)
        self.assertEqual(rsi.update(9), 0)

    def test_long(self):
        rsi = RSI(window=2, fillna=True)
        for x in range(20):
            rsi.update(22-x)
        self.assertEqual(rsi.update(1), 0)
        self.assertEqual(rsi.update(2), 25)
        self.assertEqual(rsi.update(1), 28.57142857142857)
        self.assertEqual(rsi.update(2), 37.5)

if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import TSI


class SMATest(TestCase):


    def test(self):
        tsi = TSI()
        self.assertAlmostEqual(tsi.update(1), 100)
        self.assertAlmostEqual(tsi.update(2), 100)
        self.assertAlmostEqual(tsi.update(0), 95.6521739130435)
        self.assertAlmostEqual(tsi.update(1), 92.32500296103281)


if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import PercentageVolume
from ta.momentum import PercentageVolumeOscillator as PercentageVolumeOscillator

class PercentageVolumeTest(TestCase):

    def test_against_reference(self):
        data = np.random.rand(100)
        pvo = PercentageVolume(fillna=True)
        for (x,y) in zip(PercentageVolumeOscillator(fillna=True, volume=pd.Series(data)).pvo(),
                         [pvo.update(x)['pvo'] for x in data]):
            self.assertAlmostEqual(x,y)
        pvo = PercentageVolume(fillna=True)
        for (x,y) in zip(PercentageVolumeOscillator(fillna=True, volume=pd.Series(data)).pvo_signal(),
                         [pvo.update(x)['signal'] for x in data]):
            self.assertAlmostEqual(x,y)
        pvo = PercentageVolume(fillna=True)
        for (x,y) in zip(PercentageVolumeOscillator(fillna=True, volume=pd.Series(data)).pvo_hist(),
                         [pvo.update(x)['histogram'] for x in data]):
            self.assertAlmostEqual(x,y)

    def test_against_reference_bulk(self):
        data = np.random.rand(100)
        pvo = PercentageVolume(fillna=True)
        for (x,y) in zip(PercentageVolumeOscillator(fillna=True, volume=pd.Series(data)).pvo(),
                         pvo.batch(data)['pvo']):
            self.assertAlmostEqual(x,y)
        pvo = PercentageVolume(fillna=True)
        for (x,y) in zip(PercentageVolumeOscillator(fillna=True, volume=pd.Series(data)).pvo_signal(),
                         pvo.batch(data)['signal']):
            self.assertAlmostEqual(x,y)
        pvo = PercentageVolume(fillna=True)
        for (x,y) in zip(PercentageVolumeOscillator(fillna=True, volume=pd.Series(data)).pvo_hist(),
                         pvo.batch(data)['histogram']):
            self.assertAlmostEqual(x,y)
        
        


if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import ATRP

class ATRTest(TestCase):

    def test(self):
        atr = ATRP(window=2)
        self.assertEqual(atr.update(1,2,3), 1.5)
        self.assertEqual(atr.update(1,2,4), 3.0)
        self.assertEqual(atr.update(2,3,4), 1.5)
        self.assertEqual(atr.update(2,3,4), 1.25)

if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import ROC
from ta.momentum import ROCIndicator

class EMAIndicatorTest(TestCase):
    def test_against_reference_batch(self):
        close = np.random.rand(100)+1
        roc = ROC(window=10, fillna=True)
        for (x,y) in zip(ROCIndicator(window=10, fillna=True, close=pd.Series(close)).roc(),
                         roc.batch(close)):
            self.assertAlmostEqual(x,y)

    def test_against_reference_batch_nan(self):
        close = np.random.rand(100)+1
        roc = ROC(window=10, fillna=False)
        for (x,y) in zip(ROCIndicator(window=10, fillna=False, close=pd.Series(close)).roc(),
                         roc.batch(close)):
            if math.isnan(x):
                self.assertTrue(math.isnan(y))
            else:
                self.assertAlmostEqual(x,y)


    def test_against_reference(self):
        close = np.random.rand(100)+1
        roc = ROC(window=10, fillna=True)
        for (x,y) in zip(ROCIndicator(window=10, fillna=True, close=pd.Series(close)).roc(),
                         [roc.update(x) for x in close]):
            self.assertAlmostEqual(x,y)

    def test_against_reference_nan(self):
        close = np.random.rand(100)+1
        roc = ROC(window=10, fillna=False)
        for (x,y) in zip(ROCIndicator(window=10, fillna=False, close=pd.Series(close)).roc(),
                         [roc.update(x) for x in close]):
            if math.isnan(x):
                self.assertTrue(math.isnan(y))
            else:
                self.assertAlmostEqual(x,y)

        

        

if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import AwesomeOscillator
from ta.momentum import AwesomeOscillatorIndicator as AwesomeOscillatorIndicatorReference

class EMAIndicatorTest(TestCase):

    def test_against_reference(self):
        high = np.random.rand(100)+1
        low = np.random.rand(100)
        ao = AwesomeOscillator(fillna=True)
        for (x,y) in zip(AwesomeOscillatorIndicatorReference(fillna=True, high=pd.Series(high), low=pd.Series(low)).awesome_oscillator(),
                         [ao.update(x, y) for x, y in zip(high, low)]):
            self.assertAlmostEqual(x,y)


if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import Low


class SMATest(TestCase):

    def test_na(self):
        low = Low(window=2, fillna=False)
        self.assertTrue(math.isnan(low.update(1)))
        self.assertTrue(math.isnan(low.update(2)))
        self.assertAlmostEqual(low.update(1), 1)
        self.assertAlmostEqual(low.update(2), 1)
        self.assertAlmostEqual(low.update(3), 2)
        self.assertAlmostEqual(low.update(1), 1)
        self.assertAlmostEqual(low.update(2), 1)

    def test(self):
        low = Low(window=2, fillna=True)
        self.assertAlmostEqual(low.update(1), 1)
        self.assertAlmostEqual(low.update(2), 1)
        self.assertAlmostEqual(low.update(0), 0)
        self.assertAlmostEqual(low.update(1), 0)


if __name__ == "__main__":
    main()



import math
from unittest import TestCase, main

import numpy as np
import pandas as pd

from rtta.indicator import EMA 
from ta.trend import EMAIndicator as EMAReference

class EMATest(TestCase):

    def test_against_reference(self):
        data = np.random.rand(100)
        ema = EMA(window=4, fillna=True)
        for (x,y) in zip(EMAReference(window=4, fillna=True, close=pd.Series(data)).ema_indicator(),
                         [ema.update(x) for x in data]):
            self.assertAlmostEqual(x,y)

    def test_fillna_all_ones(self):
        ema = EMA(window=4, fillna=True)
        for _ in range(10):
            self.assertAlmostEqual(ema.update(1), 1)

if __name__ == "__main__":
    main()
